@@ -1,2 +1,2 @@
-from .core import (df_to_excel, get_ecb_rates, get_last_ecb_rates)
+from .core import df_to_excel, get_ecb_rates, get_last_ecb_rates, dfs_to_excel, Camt
 __doc__ = """kktools package provides useful tools for finance and treasury specialists"""
